This is a fork of `https://github.com/invl/retry` that includes the ability to decorate async functions. See `https://github.com/invl/retry` for the README.
Also using the sync tests from the original repo.

`pip install retry-async`

For mypy:

`mypy retry_async`